coeff: coeff

Description Usage Arguments Value Examples

View source: R/coeff.R

Description

Creates a linear model using the x knots and data. The function then returns the coefficients of the linear model

Usage

1
coeff(xk, xk2, data)

Arguments

xk

the first x knot

xk2

the second k knot

data

the data for the linear model

Value

coefficients of the linear model

Examples

1
coeff(xk,xk2,data)

cil0834/MATH4773CLAG documentation built on Sept. 26, 2020, 12:03 a.m.