Description Usage Arguments Value Examples
View source: R/matrix_rsquared.R
matrix_rsquared
1 | matrix_rsquared(x1, x2, h, data)
|
x1 |
the interval for x knot 1 |
x2 |
the interval for x knot 2 |
h |
the size of the interval of each grid |
data |
the data of the linear model The function that finds the max r^2 withing the confidence interval using grid approximation |
returns x knot 1, x knot 2, and r^2
1 | matrix_rsquared(x1, x2, 0.001, spruce.df)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.