myf2: myf2

Description Usage Arguments Value Examples

View source: R/myf2.R

Description

Takes in data and x knot values to create a linear equation.

Usage

1
myf2(x, xk, xk2, coef)

Arguments

x

points on the curve

xk

the first x knot

xk2

the second k knot

coef

linear model coefficients

Value

coefficients of the linear model used for plotting linear equations

Examples

1
myf2(x,xk=input$xk1,xk2 = input$xk2, coef=coef(lmp)

cil0834/MATH4773CLAG documentation built on Sept. 26, 2020, 12:03 a.m.