rsq_xk1_xk2: rsq_xk1_xk2

Description Usage Arguments Value Examples

View source: R/rsq_xk1_xk2.R

Description

rsq_xk1_xk2

Usage

1
rsq_xk1_xk2(xk1, xk2, data)

Arguments

xk1

x knot 1

xk2

x knot 2

data

the data used in the linear model This function returns the r^2 value of the linear model given x knot 1 and x knot 2

Value

the r^2 value of the linear model given the data and the x knots

Examples

1
rsq_xk1_xk2(xk1, xk2, spruce.df)

cil0834/MATH4773CLAG documentation built on Sept. 26, 2020, 12:03 a.m.