Description Usage Arguments Value Examples
Creates a linear model using the x knots and data. The function then returns the coefficients of the linear model
1 |
xk |
the first x knot |
xk2 |
the second k knot |
data |
the data for the linear model |
coefficients of the linear model
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.