Description Usage Arguments Value Examples
Takes in data and x knot values to create a linear equation.
1 |
x |
points on the curve |
xk |
the first x knot |
xk2 |
the second k knot |
coef |
linear model coefficients |
coefficients of the linear model used for plotting linear equations
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.