Description Usage Arguments Value Examples
rsq_xk1_xk2
1 | rsq_xk1_xk2(xk1, xk2, data)
|
xk1 |
x knot 1 |
xk2 |
x knot 2 |
data |
the data used in the linear model This function returns the r^2 value of the linear model given x knot 1 and x knot 2 |
the r^2 value of the linear model given the data and the x knots
1 | rsq_xk1_xk2(xk1, xk2, spruce.df)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.